﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.IO;
using System.Linq;
using System.Threading.Tasks;
using Microsoft.AspNetCore.Hosting;
using Microsoft.AspNetCore.Mvc;
using Sample.Models;
using Syncfusion.OfficeChart;
using Syncfusion.DocIO;
using Syncfusion.DocIORenderer;
using Syncfusion.Pdf;
using Syncfusion.DocIO.DLS;

namespace Sample.Controllers
{
    public class HomeController : Controller
    {
        public IActionResult Index()
        {
            return View();
        }

        private readonly IHostingEnvironment _hostingEnvironment;

        public HomeController(IHostingEnvironment hostingEnvironment)
        {
            _hostingEnvironment = hostingEnvironment;
        }

        [HttpPost]

        public IActionResult ConvertToPDF()
        {
            //Open the file as Stream
            FileStream imageStream = new FileStream(_hostingEnvironment.WebRootPath + @"\Road-550-W.jpg", FileMode.Open, FileAccess.Read);
            WordDocument document = new WordDocument();
            //Adds new section to the document
            IWSection section = document.AddSection();
            //Adds new paragraph to the section
            IWParagraph paragraph = section.AddParagraph();
            paragraph.AppendText("Image Hyperlink");
            paragraph = section.AddParagraph();
            //Creates a new image instance and load image 
            WPicture picture = new WPicture(document);
            picture.LoadImage(imageStream);
            //Appends new image hyperlink to the paragraph
            paragraph.AppendHyperlink("http://www.syncfusion.com", picture, HyperlinkType.WebLink);
            //Instantiation of DocIORenderer for Word to PDF conversion
            DocIORenderer render = new DocIORenderer();
            //Sets Chart rendering Options.
            render.Settings.ChartRenderingOptions.ImageFormat = ExportImageFormat.Jpeg;
            //Sets a value indicating whether to embed fonts in the converted PDF document.
            render.Settings.EmbedFonts = true;
            render.Settings.EmbedCompleteFonts = true;
            //Converts Word document into PDF document
            PdfDocument pdfDocument = render.ConvertToPDF(document);
            //Releases all resources used by the Word document and DocIO Renderer objects
            render.Dispose();
            document.Dispose();
            //Create new instance of memeory stream
            MemoryStream outputStream = new MemoryStream();
            //Save the PDF into stream
            pdfDocument.Save(outputStream);
            //Set the current position of stream to 0.
            outputStream.Position = 0;
            //Initialize the file stream to download generated PDF.
            FileStreamResult fileStreamResult = new FileStreamResult(outputStream, "application/pdf");
            //Set the file name.
            fileStreamResult.FileDownloadName = "Output.pdf";
            return fileStreamResult;

        }

        public IActionResult About()
        {
            ViewData["Message"] = "Your application description page.";

            return View();
        }

        public IActionResult Contact()
        {
            ViewData["Message"] = "Your contact page.";

            return View();
        }

        public IActionResult Error()
        {
            return View(new ErrorViewModel { RequestId = Activity.Current?.Id ?? HttpContext.TraceIdentifier });
        }
    }
}
